@@ -11,9 +11,13 @@ import numpy as np
 from sklearn.base import BaseEstimator, clone, is_classifier
 
 import hiclass.data as data_utils
-from hiclass import BinaryPolicies
-from hiclass.data import (CATEGORICAL_ROOT_NODE, NODE_TYPE, SEPARATOR,
-                          minimal_per_node_depth)
+from hiclass import Policies
+from hiclass.data import (
+    CATEGORICAL_ROOT_NODE,
+    NODE_TYPE,
+    SEPARATOR,
+    minimal_per_node_depth,
+)
 
 
 class Classifier(abc.ABC):
@@ -29,7 +33,7 @@ class Classifier(abc.ABC):
         verbose: int = 0,
         local_classifier: Any = BaseEstimator(),
         hierarchy: Optional[nx.DiGraph] = None,
-        unique_taxonomy: bool = True
+        unique_taxonomy: bool = True,
     ):
         """
         Initialize a classifier.
@@ -338,7 +342,7 @@ class NodeClassifier(Classifier, abc.ABC):
         local_classifier: Any = BaseEstimator(),
         hierarchy: Optional[nx.DiGraph] = None,
         unique_taxonomy: bool = True,
-        policy: Union[str, Type[BinaryPolicies.Policy]] = "siblings",
+        policy: Union[str, Type[Policies.Policy]] = "siblings",
     ):
         """
         Initialize a classifier.
@@ -371,7 +375,7 @@ class NodeClassifier(Classifier, abc.ABC):
             verbose=verbose,
             local_classifier=local_classifier,
             hierarchy=hierarchy,
-            unique_taxonomy=unique_taxonomy
+            unique_taxonomy=unique_taxonomy,
         )
 
     def _specialize_prediction(
@@ -465,7 +469,7 @@ class NodeClassifier(Classifier, abc.ABC):
         labels = data_utils.flatten_labels(Y, self.placeholder_label)
         if type(self.policy) == str:
             try:
-                self.policy = BinaryPolicies.IMPLEMENTED_POLICIES[self.policy.lower()](
+                self.policy = Policies.IMPLEMENTED_POLICIES[self.policy.lower()](
                     self.hierarchy, labels
                 )
             except KeyError:
@@ -473,7 +477,7 @@ class NodeClassifier(Classifier, abc.ABC):
                     KeyError,
                     self.log,
                     f"Policy {self.policy} not implemented. Available policies are:\n"
-                    f"{list(BinaryPolicies.IMPLEMENTED_POLICIES.keys())}",
+                    f"{list(Policies.IMPLEMENTED_POLICIES.keys())}",
                 )
         else:
             self.policy = self.policy(self.hierarchy, labels)
